==> myfaces-core-assembly-2.0.25-src.zip: myfaces-core-module-2.0.25/impl/src/test/java/org/apache/myfaces/spi/FactoryFinderProviderTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.spi;

import javax.faces.FactoryFinder;

import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.junit.experimental.theories.Theory;

public class FactoryFinderProviderTest
{

    public FactoryFinderProviderTest()
    {
        super();
    }

    @Before
    public void setUp() throws Exception
    {
    }

    @After
    public void tearDown() throws Exception
    {
        
    }
    
    @Test
    public void testGetFactory() throws Exception
    {
        FactoryFinderProviderFactory ffp = new CustomFactoryFinderProviderFactoryImpl();
     
        FactoryFinderProviderFactory.setInstance(ffp);
        
        Object uno = FactoryFinder.getFactory("anything");
        
        Assert.assertEquals(1, uno);
        
        FactoryFinder.setFactory(FactoryFinder.APPLICATION_FACTORY, "sfdsfdsf");
        
        FactoryFinder.releaseFactories();
        
        
    }
    
}

==> myfaces-core-assembly-3.0.2-src.zip: myfaces-core-module-3.0.2/impl/src/test/java/org/apache/myfaces/spi/FactoryFinderProviderTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.spi;

import jakarta.faces.FactoryFinder;

import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

public class FactoryFinderProviderTest
{

    public FactoryFinderProviderTest()
    {
        super();
    }

    @Before
    public void setUp() throws Exception
    {
    }

    @After
    public void tearDown() throws Exception
    {
        
    }
    
    @Test
    public void testGetFactory() throws Exception
    {
        FactoryFinderProviderFactory ffp = new CustomFactoryFinderProviderFactoryImpl();
     
        FactoryFinderProviderFactory.setInstance(ffp);
        
        Object uno = FactoryFinder.getFactory("anything");
        
        Assert.assertEquals(1, uno);
        
        FactoryFinder.setFactory(FactoryFinder.APPLICATION_FACTORY, "sfdsfdsf");
        
        FactoryFinder.releaseFactories();
        
        
    }
    
}
